<?php

namespace App\Http\Controllers\User;

use App\Plan;
use App\User;
use App\Theme;
use App\Gallery;
use App\Payment;
use App\Service;
use App\Setting;
use App\Category;
use Carbon\Carbon;
use App\ContactForm;
use App\BusinessCard;
use App\BusinessHour;
use App\StoreProduct;
use App\VcardProduct;
use App\BusinessField;
use Illuminate\Http\Request;
use Yajra\DataTables\DataTables;
use Illuminate\Support\Facades\DB;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;

class CardController extends Controller
{
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('auth');
    }

    /**
     * Show the application dashboard.
     *
     * @return \Illuminate\Contracts\Support\Renderable
     */

    // All user cards
    public function index(Request $request)
    {
        // Queries
        $active_plan = Plan::where('plan_id', Auth::user()->plan_id)->first();
        $plan = User::where('user_id', Auth::user()->user_id)->first();
        $active_plan = json_decode($plan->plan_details);

        if ($active_plan != null) {
            if ($request->ajax()) {
                $businessCards = DB::table('business_cards')
                    ->join('users', 'business_cards.user_id', '=', 'users.user_id')
                    ->select('users.user_id', 'users.plan_validity', 'business_cards.*')
                    ->where('business_cards.user_id', Auth::user()->user_id)
                    ->where('business_cards.card_type', 'vcard')
                    ->where('business_cards.status', 1)
                    ->where('business_cards.card_status', '!=', 'deleted')
                    ->orderBy('business_cards.id', 'desc')
                    ->get();

                return DataTables::of($businessCards)
                    ->addIndexColumn()
                    ->editColumn('created_at', function ($card) {
                        return Carbon::parse($card->created_at)->format('d-m-Y h:i A');
                    })
                    ->editColumn('title', function ($card) {
                        return '<strong>' . $card->title . '</strong>';
                    })
                    ->editColumn('card_type', function ($card) {
                        return $card->card_type == 'vcard' ? __('vCard') : __('WhatsApp Store');
                    })
                    ->editColumn('plan_validity', function ($card) {
                        return date('d/M/Y', strtotime($card->plan_validity));
                    })
                    ->editColumn('card_status', function ($card) {
                        return $card->card_status == 'inactive'
                            ? '<span class="badge bg-red text-white text-white">' . __('Inactive') . '</span>'
                            : '<span class="badge bg-green text-white text-white">' . __('Active') . '</span>';
                    })
                    ->addColumn('action', function ($card) {
                        $config = DB::table('config')->get();

                        $actionBtn = '';
                        $actionBtn .= $config[46]->config_value == '1'
                            ? '<a class="dropdown-item open-qr" onclick="updateQr(`' . route('subdomain.profile', $card->card_url) . '`)">' . __('Scan QR') . '</a>'
                            : '<a class="dropdown-item open-qr" onclick="updateQr(`' . route('profile', $card->card_url) . '`)">' . __('Scan QR') . '</a>';
                        $actionBtn .= '<a class="dropdown-item" href="' . route('user.edit.card', $card->card_id) . '">' . __('Edit') . '</a>';
                        $actionBtn .= '<a class="dropdown-item" href="' . route('user.view.preview', $card->card_id) . '" target="_blank">' . __('Preview') . '</a>';
                        $actionBtn .= $config[46]->config_value == '1'
                            ? '<a class="dropdown-item" href="' . route('subdomain.profile', $card->card_url) . '" target="_blank">' . __('Live') . '</a>'
                            : '<a class="dropdown-item" href="' . route('profile', $card->card_url) . '" target="_blank">' . __('Live') . '</a>';
                        $actionBtn .= '<a class="dropdown-item" href="' . route('user.visitors', $card->card_url) . '">' . __('Visitors') . '</a>';
                        if ($card->card_type == "vcard") {
                            $actionBtn .= '<a class="dropdown-item" href="' . route('user.enquiries', $card->card_id) . '">' . __('Enquiries') . '</a>';
                        }
                        $actionBtn .= $card->card_status == 'activated'
                            ? '<a class="open-model dropdown-item" data-id="' . $card->card_id . '" href="#openModel">' . __('Disable') . '</a>'
                            : '<a class="open-model dropdown-item" data-id="' . $card->card_id . '" href="#openModel">' . __('Enable') . '</a>';
                        $actionBtn .= '<a class="dropdown-item" onclick="deleteCard(`' . $card->card_id . '`, `delete`); return false;">' . __('Delete') . '</a>';

                        return '<span class="dropdown"><button class="btn small-btn dropdown-toggle align-text-top" data-bs-boundary="viewport" data-bs-toggle="dropdown" aria-expanded="false">' . __('Actions') . '</button><div class="dropdown-menu dropdown-menu-end" style="">' . $actionBtn . '</div></span>';
                    })
                    ->rawColumns(['title', 'card_status', 'action'])
                    ->make(true);
            }

            $config = DB::table('config')->get();
            $settings = Setting::where('status', 1)->first();

            return view('user.pages.cards.cards', compact('settings', 'config'));
        } else {
            return redirect()->route('user.plans');
        }
    }

    // Choose a card type
    public function chooseCardType()
    {
        // Queries
        $settings = Setting::where('status', 1)->first();

        $cards = BusinessCard::where('user_id', Auth::user()->user_id)->where('card_type', 'vcard')->where('card_status', 'activated')->count();

        // Active plan details in user
        $plan = DB::table('users')->where('user_id', Auth::user()->user_id)->where('status', 1)->first();
        $plan_details = json_decode($plan->plan_details);

        // Check validity
        $validity = User::where('user_id', Auth::user()->user_id)->whereDate('plan_validity', '>=', Carbon::now())->count();

        // Check unlimited cards
        if ($plan_details->no_of_vcards == 999) {
            $no_cards = 999999;
        } else {
            $no_cards = $plan_details->no_of_vcards;
        }

        // Check vcard creation limit
        if ($validity == 1) {
            if ($cards < $no_cards) {
                return view('user.pages.cards.choose-a-card', compact('settings', 'plan_details'));
            } else {
                return redirect()->route('user.cards')->with('failed', trans('The maximum limit has been exceeded. Please upgrade your plan.'));
            }
        } else {
            // Redirect
            return redirect()->route('user.cards')->with('failed', trans('Your plan is over. Choose your plan renewal or new package and use it.'));
        }
    }

    // Skip business hours
    public function skipAndSave()
    {
        // Redirect
        return redirect()->route('user.cards')->with('success', trans('Your virtual business card is updated!'));
    }

    // Card Status Page
    public function cardStatus(Request $request, $id)
    {
        // Queries
        $businessCard = BusinessCard::where('card_id', $id)->first();

        // Check business card
        if ($businessCard == null) {
            return redirect()->route('user.cards')->with('failed', trans('Card not found!'));
        } else {

            // Queries
            $business_card = BusinessCard::where('user_id', Auth::user()->user_id)->where('card_id', $id)->first();

            // Check business card
            if ($business_card == null) {
                return redirect()->route('user.cards')->with('failed', trans('Card not found!'));
            } else {
                // Check active cards
                if ($business_card->card_status == 'inactive') {

                    // Queries
                    $plan = User::where('user_id', Auth::user()->user_id)->first();
                    $active_plan = json_decode($plan->plan_details);

                    // vCard
                    if ($business_card->card_type == "vcard") {
                        // vCard
                        $no_of_services = Service::where('card_id', $id)->count();
                        $no_of_vcard_products = VcardProduct::where('card_id', $id)->count();
                        $no_of_links = BusinessField::where('card_id', $id)->count();
                        $no_of_payments = Payment::where('card_id', $id)->count();
                        $no_of_galleries = Gallery::where('card_id', $id)->count();
                        $business_hours = BusinessHour::where('card_id', $id)->count();
                        $contact_form = ContactForm::where('card_id', $id)->count();

                        // Check vcard / store limitation
                        if ($no_of_services <= $active_plan->no_of_services && $no_of_vcard_products <= $active_plan->no_of_vcard_products && $no_of_galleries <= $active_plan->no_of_galleries && $no_of_links <= $active_plan->no_of_links && $no_of_payments <= $active_plan->no_of_payments) {

                            // Queries (vCards)
                            $cards = BusinessCard::where('user_id', Auth::user()->user_id)->where('card_type', 'vcard')->where('card_status', 'activated')->count();

                            // Get plan details in user
                            $plan = DB::table('users')->where('user_id', Auth::user()->user_id)->where('status', 1)->first();
                            $plan_details = json_decode($plan->plan_details);

                            // Number of vcards limitation
                            if ($cards < $plan_details->no_of_vcards) {

                                // Update (vCard)
                                BusinessCard::where('user_id', Auth::user()->user_id)->where('card_type', 'vcard')->where('card_id', $id)->update([
                                    'card_status' => 'activated',
                                ]);

                                return redirect()->route('user.cards')->with('success', trans('Your vcard activated.'));
                            } else {

                                return redirect()->route('user.cards')->with('failed', trans('The maximum limit has been exceeded. Please upgrade your plan.'));
                            }
                        } else {
                            // Queries
                            $cards = BusinessCard::where('user_id', Auth::user()->user_id)->where('card_type', 'vcard')->where('card_status', 'activated')->count();

                            // Get plan details in user
                            $plan = DB::table('users')->where('user_id', Auth::user()->user_id)->where('status', 1)->first();
                            $plan_details = json_decode($plan->plan_details);

                            // Number of vcards limitation
                            if ($cards < $plan_details->no_of_vcards) {
                                return redirect()->route('user.edit.card', $id)->with('failed', 'You have downgraded your plan. Please re-configure this vcard as per your current plan features.');
                            } else {
                                return redirect()->route('user.cards')->with('failed', trans('The maximum limit has been exceeded. Please upgrade your plan.'));
                            }
                        }
                    }

                    // Store
                    if ($business_card->card_type == "store") {
                        // Store
                        $no_of_categories = Category::where('user_id', auth::user()->user_id)->count();
                        $no_of_store_products = StoreProduct::where('card_id', $id)->count();

                        // Check vcard / store limitation
                        if ($no_of_categories <= $active_plan->no_of_categories && $no_of_store_products <= $active_plan->no_of_store_products) {

                            // Queries (Stores)
                            $stores = BusinessCard::where('user_id', Auth::user()->user_id)->where('card_type', 'store')->where('card_status', 'activated')->count();

                            // Get plan details in user
                            $plan = DB::table('users')->where('user_id', Auth::user()->user_id)->where('status', 1)->first();
                            $plan_details = json_decode($plan->plan_details);

                            // Number of stores limitation
                            if ($stores < $plan_details->no_of_stores) {

                                // Update (Stores)
                                BusinessCard::where('user_id', Auth::user()->user_id)->where('card_type', 'store')->where('card_id', $id)->update([
                                    'card_status' => 'activated',
                                ]);

                                return redirect()->route('user.stores')->with('success', trans('Your store link was activated.'));
                            } else {
                                return redirect()->route('user.stores')->with('failed', trans('The maximum limit has been exceeded. Please upgrade your plan.'));
                            }
                        } else {

                            // Queries (Stores)
                            $stores = BusinessCard::where('user_id', Auth::user()->user_id)->where('card_type', 'store')->where('card_status', 'activated')->count();

                            // Get plan details in user
                            $plan = DB::table('users')->where('user_id', Auth::user()->user_id)->where('status', 1)->first();
                            $plan_details = json_decode($plan->plan_details);

                            // Number of stores limitation
                            if ($stores < $plan_details->no_of_stores) {
                                return redirect()->route('user.edit.store', $id)->with('failed', 'You have downgraded your plan. Please re-configure this vcard as per your current plan features.');
                            } else {
                                return redirect()->route('user.stores')->with('failed', trans('The maximum limit has been exceeded. Please upgrade your plan.'));
                            }
                        }
                    }
                } else {
                    // Update
                    BusinessCard::where('user_id', Auth::user()->user_id)->where('card_id', $id)->update([
                        'card_status' => 'inactive',
                    ]);

                    return redirect()->back()->with('success', trans('Deactivated'));
                }
            }
        }
    }

    // Delete card
    public function deleteCard(Request $request)
    {
        // Delete
        BusinessCard::where('user_id', Auth::user()->user_id)->where('card_id', $request->query('id'))->update([
            'card_status' => 'deleted',
        ]);

        return redirect()->route('user.cards')->with('success', trans('Card Deleted!'));
    }

    // Search by theme
    public function searchTheme(Request $request)
    {
        $query = $request->get('query');
        $type = $request->get('type');

        $cards = Theme::where('theme_name', 'LIKE', '%' . $query . '%')->where('theme_description', $type)->where('status', 1)->get();

        return response()->json($cards);
    }
}
