<?php

namespace App\Http\Controllers\User;

use App\Plan;
use App\User;
use App\Setting;
use Carbon\Carbon;
use App\BusinessCard;
use Illuminate\Http\Request;
use Yajra\DataTables\DataTables;
use Illuminate\Support\Facades\DB;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;

class StoreController extends Controller
{
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('auth');
    }

    /**
     * Show the application dashboard.
     *
     * @return \Illuminate\Contracts\Support\Renderable
     */

    // All user stores
    public function index(Request $request)
    {
        $active_plan = Plan::where('plan_id', Auth::user()->plan_id)->first();
        $plan = User::where('user_id', Auth::user()->user_id)->first();
        $active_plan = json_decode($plan->plan_details);

        if ($active_plan != null) {
            if ($request->ajax()) {
                $business_cards = DB::table('business_cards')
                    ->join('users', 'business_cards.user_id', '=', 'users.user_id')
                    ->select('users.user_id', 'users.plan_validity', 'business_cards.*')
                    ->where('business_cards.user_id', Auth::user()->user_id)
                    ->where('business_cards.card_type', 'store')
                    ->where('business_cards.status', 1)
                    ->where('business_cards.card_status', '!=', 'deleted')
                    ->orderBy('business_cards.id', 'desc')
                    ->get();

                return DataTables::of($business_cards)
                    ->addIndexColumn()
                    ->editColumn('created_at', function ($card) {
                        return Carbon::parse($card->created_at)->format('d-m-Y h:i A');
                    })
                    ->editColumn('title', function ($card) {
                        return '<strong>' . $card->title . '</strong>';
                    })
                    ->editColumn('card_type', function ($card) {
                        return $card->card_type == 'vcard' ? __('vCard') : __('WhatsApp Store');
                    })
                    ->editColumn('plan_validity', function ($card) {
                        return date('d/M/Y', strtotime($card->plan_validity));
                    })
                    ->editColumn('card_status', function ($card) {
                        return $card->card_status == 'inactive'
                            ? '<span class="badge bg-red text-white text-white">' . __('Inactive') . '</span>'
                            : '<span class="badge bg-green text-white text-white">' . __('Active') . '</span>';
                    })
                    ->addColumn('action', function ($card) {
                        $config = DB::table('config')->get();
                        $actionBtn = '';

                        $actionBtn .= $config[46]->config_value == '1'
                            ? '<a class="dropdown-item open-qr" onclick="updateQr(`' . route('subdomain.profile', $card->card_url) . '`)">' . __('Scan QR') . '</a>'
                            : '<a class="dropdown-item open-qr" onclick="updateQr(`' . route('profile', $card->card_url) . '`)">' . __('Scan QR') . '</a>';
                        $actionBtn .= '<a class="dropdown-item" href="' . route('user.edit.card', $card->card_id) . '">' . __('Edit') . '</a>';
                        $actionBtn .= '<a class="dropdown-item" href="' . route('user.view.preview', $card->card_id) . '" target="_blank">' . __('Preview') . '</a>';
                        $actionBtn .= $config[46]->config_value == '1'
                            ? '<a class="dropdown-item" href="' . route('subdomain.profile', $card->card_url) . '" target="_blank">' . __('Live') . '</a>'
                            : '<a class="dropdown-item" href="' . route('profile', $card->card_url) . '" target="_blank">' . __('Live') . '</a>';
                        $actionBtn .= '<a class="dropdown-item" href="' . route('user.visitors', $card->card_url) . '">' . __('Visitors') . '</a>';

                        if ($card->card_type == "vcard") {
                            $actionBtn .= '<a class="dropdown-item" href="' . route('user.enquiries', $card->card_id) . '">' . __('Enquiries') . '</a>';
                        }
                        $actionBtn .= $card->card_status == 'activated'
                            ? '<a class="open-model dropdown-item" data-id="' . $card->card_id . '" href="#openModel">' . __('Disable') . '</a>'
                            : '<a class="open-model dropdown-item" data-id="' . $card->card_id . '" href="#openModel">' . __('Enable') . '</a>';
                        $actionBtn .= '<a class="dropdown-item" onclick="deleteStore(`' . $card->card_id . '`, `delete`); return false;">' . __('Delete') . '</a>';

                        return '<span class="dropdown"><button class="btn small-btn dropdown-toggle align-text-top" data-bs-boundary="viewport" data-bs-toggle="dropdown" aria-expanded="false">' . __('Actions') . '</button><div class="dropdown-menu dropdown-menu-end" style="">' . $actionBtn . '</div></span>';
                    })
                    ->rawColumns(['title', 'card_status', 'action'])
                    ->make(true);
            }

            $config = DB::table('config')->get();
            $settings = Setting::where('status', 1)->first();

            return view('user.pages.stores.index', compact('settings', 'config'));
        } else {
            return redirect()->route('user.plans');
        }
    }

    // Delete store
    public function deleteStore(Request $request)
    {
        // Delete
        BusinessCard::where('user_id', Auth::user()->user_id)->where('card_id', $request->query('id'))->update([
            'card_status' => 'deleted',
        ]);

        return redirect()->route('user.stores')->with('success', trans('Removed!'));
    }
}
