<?php

namespace App\Http\Controllers\User;

use App\Plan;
use App\User;
use App\Setting;
use App\Currency;
use App\Transaction;
use Illuminate\Http\Request;
use Yajra\DataTables\DataTables;
use Illuminate\Support\Facades\DB;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;

class TransactionsController extends Controller
{
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('auth');
    }

    /**
     * Show the application dashboard.
     *
     * @return \Illuminate\Contracts\Support\Renderable
     */

    public function indexTransactions(Request $request)
    {
        $active_plan = Plan::where('plan_id', Auth::user()->plan_id)->first();
        $plan = User::where('user_id', Auth::user()->user_id)->first();
        $active_plan = json_decode($plan->plan_details);

        if ($active_plan != null) {
            if ($request->ajax()) {
                $transactions = Transaction::where('user_id', Auth::user()->id)->orderBy('id', 'desc')->get();
                
                return DataTables::of($transactions)
                    ->addIndexColumn()
                    ->addColumn('created_at', function ($transaction) {
                        return $transaction->created_at->format('d-m-Y H:i:s A');
                    })
                    ->addColumn('payment_gateway_name', function ($transaction) {
                        return __($transaction->payment_gateway_name);
                    })
                    ->addColumn('transaction_amount', function ($transaction) {
                        return Currency::where('iso_code', $transaction->transaction_currency)->first()->symbol . $transaction->transaction_amount;
                    })
                    ->addColumn('payment_status', function ($transaction) {
                        if ($transaction->payment_status == 'SUCCESS') {
                            return '<span class="badge bg-green text-white">' . __('Paid') . '</span>';
                        } elseif ($transaction->payment_status == 'FAILED') {
                            return '<span class="badge bg-red text-white">' . __('Failed') . '</span>';
                        } else {
                            return '<span class="badge bg-yellow text-white">' . __('Pending') . '</span>';
                        }
                    })
                    ->addColumn('action', function ($transaction) {
                        if ($transaction->invoice_number > 0) {
                            return '<span class="dropdown">
                                    <button class="btn dropdown-toggle align-text-top small-btn" data-bs-boundary="viewport" data-bs-toggle="dropdown" aria-expanded="false">' . __('Actions') . '</button>
                                    <div class="dropdown-menu dropdown-menu-end" style="">
                                        <a class="dropdown-item" href="' . route('user.view.invoice', ['id' => $transaction->gobiz_transaction_id]) . '">' . __('Invoice') . '</a>
                                    </div>
                                </span>';
                        }
                    })
                    ->rawColumns(['payment_status', 'action'])
                    ->make(true);
            }

            $settings = Setting::where('status', 1)->first();
            $currencies = Currency::get();

            return view('user.pages.transactions.index', compact('settings', 'currencies'));
        } else {
            return redirect()->route('user.plans');
        }
    }

    // View invoice
    public function viewInvoice($id)
    {
        // Queries
        $transaction = Transaction::where('gobiz_transaction_id', $id)->first();

        if ($transaction) {
            $settings = Setting::where('status', 1)->first();
            $config = DB::table('config')->get();
            $currencies = Currency::get();
            $transaction['billing_details'] = json_decode($transaction['invoice_details'], true);

            return view('user.pages.transactions.view-invoice', compact('transaction', 'settings', 'config', 'currencies'));
        } else {
            return back()->with('failed', trans('Invoice not found!'));
        }
    }
}
