<!doctype html>
<html lang="{{ str_replace('_', '-', app()->getLocale()) }}">

<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">

    <!-- CSRF Token -->
    <meta name="csrf-token" content="{{ csrf_token() }}">

    {{-- SEO --}}
    @if (isset($setting) && $setting)
        {!! SEOMeta::generate() !!}
        {!! OpenGraph::generate() !!}
        {!! Twitter::generate() !!}
        {!! JsonLd::generate() !!}
    @endif

    {{-- Title --}}
    @if (isset($title) && $title)
        <title>{{ $title }}</title>
    @endif

    {{-- Google verification --}}
    @if (isset($setting) && $setting)
        <meta name="google-site-verification" content="{{ $settings->google_key }}">
        <link rel="icon" href="{{ asset($settings->favicon) }}" sizes="96x96" type="image/png" />
    @endif

    {!! htmlScriptTagJsApi() !!}

    <!-- CSS files -->
    <link rel="stylesheet" href="{{ asset('app/css/tailwind.min.css') }}">
    <link rel="stylesheet" href="{{ asset('app/css/style.css') }}">
    <link rel="stylesheet" href="{{ asset('css/sweetalert.min.css') }}">
    <link rel="stylesheet" href="{{ asset('css/fontawesome.min.css') }}" />
    <script type="text/javascript" src="{{ asset('app/js/main.js') }}"></script>
    <script type="text/javascript" src="{{ asset('js/alpine.min.js') }}"></script>
    <script type="text/javascript" src="{{ asset('js/jquery.min.js') }}"></script>
    <script type="text/javascript" src="{{ asset('js/sweetalert.min.js') }}"></script>

    @if (isset($setting) && $setting)
        {{-- Check Google Analytics is "enabled" --}}
        @if (!empty($settings->google_analytics_id))
            <!-- Global site tag (gtag.js) - Google Analytics -->
            <script async src="https://www.googletagmanager.com/gtag/js?id={{ $settings->google_analytics_id }}"></script>
            <script>
                window.dataLayer = window.dataLayer || [];

                function gtag() {
                    dataLayer.push(arguments);
                }
                gtag('js', new Date());

                gtag('config', '{{ $settings->google_analytics_id }}');
            </script>
        @endif
    @endif

    @if ($settings->google_adsense_code != 'DISABLE_ADSENSE_ONLY')
    {{-- AdSense code --}}
    <script async src="https://pagead2.googlesyndication.com/pagead/js/adsbygoogle.js?client={{ $settings->google_adsense_code }}"
        crossorigin="anonymous"></script>
    @endif

    {{-- Custom CSS / JS --}}
    @yield('custom-script')

    <style>
        .skeleton {
            background-color: #e0e0e0;
            border-radius: 4px;
            width: 50px;
            height: 50px;
            position: relative;
            overflow: hidden;
        }

        .skeleton::after {
            content: "";
            display: block;
            position: absolute;
            top: 0;
            left: 0;
            width: 100%;
            height: 100%;
            transform: translateX(-100%);
            background: linear-gradient(90deg, rgba(255, 255, 255, 0) 0%, rgba(255, 255, 255, 0.2) 50%, rgba(255, 255, 255, 0) 100%);
            animation: loading 1.5s infinite;
        }

        @keyframes loading {
            100% {
                transform: translateX(100%);
            }
        }

        .icon-placeholder {
            width: 50px;
            height: 50px;
        }

        .plan-icon-placeholder {
            width: 20px;
            height: 20px;
        }
    </style>
</head>

<body class="antialiased bg-body text-body font-body"
    dir="{{ App::isLocale('ar') || App::isLocale('ur') || App::isLocale('he') ? 'rtl' : 'ltr' }}">

    <div class="">
        {{-- Header --}}
        @if (isset($nav) && $nav)
            @include('website.includes.header')
        @endif

        {{-- Page Content --}}
        @yield('content')

        {{-- Cookie consent --}}
        @if (env('COOKIE_CONSENT_ENABLED') == true)
            @include('cookie-consent::index')
        @endif
    </div>

    {{-- WhatsApp Chatbot --}}
    @if ($config[40]->config_value == '1')
        <a href="https://api.whatsapp.com/send?phone={{ $config[41]->config_value }}&text={{ urlencode($config[42]->config_value) }}"
            class="whatapp-chatbot" target="_blank">
            <i class="fab fa-whatsapp whatapp-chatbot-icon"></i>
        </a>
    @endif

    {{-- Tawk.to Chat --}}
    @if (isset($settings) && $settings)
        @if ($settings->tawk_chat_bot_key != null && $config[40]->config_value != '1')
            <!--Start of Tawk.to Script-->
            <script>
                (function($) {
                    "use strict";
                    var Tawk_API = Tawk_API || {},
                        Tawk_LoadStart = new Date();
                    var s1 = document.createElement("script"),
                        s0 = document.getElementsByTagName("script")[0];
                    s1.async = true;
                    s1.src = 'https://embed.tawk.to/{{ $settings->tawk_chat_bot_key }}';
                    s1.charset = 'UTF-8';
                    s1.setAttribute('crossorigin', '*');
                    s0.parentNode.insertBefore(s1, s0);
                })(jQuery);
            </script>
            <!--End of Tawk.to Script-->
        @endif
    @endif

    {{-- Footer --}}
    @if (isset($footer) && $footer)
        @include('website.includes.footer')
    @endif

    <!-- Smooth Scroll -->
    <script type="text/javascript" src="{{ asset('js/smooth-scroll.polyfills.min.js') }}"></script>
    <script type="text/javascript" src="{{ asset('app/js/footer.js') }}"></script>

    <script async>
        // Initially hide the skeleton elements
        const skeletonElements = document.querySelectorAll('.skeleton');
        skeletonElements.forEach((element) => {
            element.style.display = 'block';
        });

        // Create a new <link> element
        var linkElement = document.createElement("link");
        linkElement.rel = "stylesheet";
        linkElement.href = "{{ asset('icons/webfont/tabler-icons.min.css') }}";

        // Append the <link> element to the <head> section of the document
        document.head.appendChild(linkElement);

        // Wait until all resources are fully loaded
        window.onload = function() {
            const skeletonIcons = document.querySelectorAll('.skeleton.icon-placeholder, .skeleton.plan-icon-placeholder');
            skeletonIcons.forEach((skeletonIcon) => {
                // Get the icon class from data attribute
                const iconClass = skeletonIcon.getAttribute('data-icon-class');

                // Create actual icon element
                const newIcon = document.createElement('i');
                newIcon.classList.add('ti', iconClass, 'rounded-lg', 'mr-2.5', 'text-green-500');

                // Check if the additional classes should be added
                if (skeletonIcon.classList.contains('plan-icon-placeholder')) {
                    // Add font size 20px if the placeholder has class plan-icon-placeholder
                    newIcon.style.fontSize = '20px';
                } else if (skeletonIcon.classList.contains('icon-placeholder')) {
                    // Add default classes if the condition is not met
                    newIcon.classList.add('p-3', 'bg-{{ $config[11]->config_value }}-100',
                        'text-{{ $config[11]->config_value }}-600');
                }

                // Replace skeleton with actual icon
                skeletonIcon.replaceWith(newIcon);
            });

            // Show the skeleton elements after everything is loaded
            skeletonElements.forEach((element) => {
                element.style.display = 'hidden';
            });
        };
    </script>

    {{-- Custom JS --}}
    @yield('custom-js')
</body>

</html>
